yakumo.neutron.v2.subnet.Manager

Package yakumo :: Package neutron :: Package v2 :: Module subnet :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for subnets in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for subnets in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.subnet.Resource |
create(self, name=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, allocation_pools=`'``__UNDEF__``'`, gateway_ip=`'``__UNDEF__``'`, ip_version=`'``__UNDEF__``'`, cidr=`'``__UNDEF__``'`, is_dhcp_enabled=`'``__UNDEF__``'`, dns_nameservers=`'``__UNDEF__``'`, host_routes=`'``__UNDEF__``'`, ipv6_ra_mode=`'``__UNDEF__``'`, ipv6_address_mode=`'``__UNDEF__``'`) Create a subnet | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``subnet``'``
| _json_resources_key = ``'``subnets``'``
| _url_resource_path = ``'``/v2.0/subnets``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, allocation_pools=`'``__UNDEF__``'`, gateway_ip=`'``__UNDEF__``'`, ip_version=`'``__UNDEF__``'`, cidr=`'``__UNDEF__``'`, is_dhcp_enabled=`'``__UNDEF__``'`, dns_nameservers=`'``__UNDEF__``'`, host_routes=`'``__UNDEF__``'`, ipv6_ra_mode=`'``__UNDEF__``'`, ipv6_address_mode=`'``__UNDEF__``'`) | source code
Create a subnet Parameters: `name` (str) - Subnet name `network` (yakumo.neutron.v2.network.Resource) - Network `project` (yakumo.project.Resource) - Project `allocation_pools` (str) - Allocation pools `gateway_ip` (str) - Gateway IP address `ip_version` (int) - IP version `cidr` (str) - CIDR `is_dhcp_enabled` (bool) - Whether DHCP is enabled `dns_nameservers` (str) - DNS nameservers `host_routes` (str) - Host routes `ipv6_ra_mode` (str) - IPv6 RA mode `ipv6_address_mode` (str) - IPv6 address mode Returns: yakumo.neutron.v2.subnet.Resource Created subnet Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('network',
       'network_id', mapper.Resource('neutron.network')), ('gateway_ip', 'ga
      teway_ip', mapper.Noop), ('dns_nameservers', 'dns_nameservers', mapper
      .Noop), ('host_route', 'host_route', mapper.Noop), ('ip_version', 'ip_
      version', mapper.Noop), ('cidr', 'cidr', mapper.Noop), ('is_dhcp_enabl
      ed', 'enable_dhcp', mapper.Noop), ('ipv6_ra_mode', 'ipv6_ra_mode', map
      per.Noop), ('ipv6_address_mode', 'ipv6_address_mode', mapper.Noop),]